==> haskell-monadrandom-0.6.2-81.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-KCyUQJdYxG7BHsWXhmeF14
key:                  MonadRandom-0.6.2-KCyUQJdYxG7BHsWXhmeF14
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  ea697fe2ddf3f886ddf052fbfac8a03e
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-KCyUQJdYxG7BHsWXhmeF14
depends:
    base-4.18.2.1 mtl-2.3.1 primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.6.2-82-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MonadRandom
version:              0.6.2
visibility:           public
id:                   MonadRandom-0.6.2-83df9fO2JvCGmEJ31Pqcbj
key:                  MonadRandom-0.6.2-83df9fO2JvCGmEJ31Pqcbj
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  4f0eaf1b41b586dc61c2fcce89f7600f
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MonadRandom-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadrandom
hs-libraries:         HSMonadRandom-0.6.2-83df9fO2JvCGmEJ31Pqcbj
depends:
    base-4.18.2.1 mtl-2.3.1 primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
